Learn R Programming

basicspace (version 0.25)

plot.blackbt: Blackbox Transpose Coordinate Distribution Plot

Description

plot.blackbt reads an blackbt object and plots the probability distribution of the respondents and stimuli.

Usage

# S3 method for blackbt
plot(x, xlim=c(-1,1), ...)

Value

A plot of the probability distribution of the respondent ideal points, along with the locations of the stimuli.

Arguments

x

an blackbt output object.

xlim

vector of length 2, fed to the plot function as the xlim argument, which sets the minimum and maximum range of the x-axis.

...

other arguments to plot.

Author

Keith Poole [email protected]

Howard Rosenthal [email protected]

Jeffrey Lewis [email protected]

James Lo [email protected]

Royce Carroll [email protected]

Christopher Hare [email protected]

References

David A. Armstrong II, Ryan Bakker, Royce Carroll, Christopher Hare, Keith T. Poole, and Howard Rosenthal. 2021. Analyzing Spatial Models of Choice and Judgment. 2nd ed. Statistics in the Social and Behavioral Sciences Series. Boca Raton, FL: Chapman & Hall/CRC. doi: 10.1201/9781315197609

Keith T. Poole, Jeffrey B. Lewis, Howard Rosenthal, James Lo, and Royce Carroll. 2016. ``Recovering a Basic Space from Issue Scales in R.'' Journal of Statistical Software 69(7): 1-21. doi:10.18637/jss.v069.i07

Keith T. Poole. 1998. ``Recovering a Basic Space From a Set of Issue Scales.'' American Journal of Political Science 42(3): 954-993. doi: 10.2307/2991737

See Also

'blackbox_transpose', 'LC1980', 'plotcdf.blackbt', 'summary.blackbt', 'LC1980_bbt'.

Examples

Run this code
  ### Loads and scales the Liberal-Conservative scales from the 1980 ANES.
  data(LC1980)
  LCdat <- LC1980[,-1]	#Dump the column of self-placements

  # \donttest{ 
  LC1980_bbt <- blackbox_transpose(LCdat, missing=c(0,8,9), dims=3, 
    minscale=5, verbose=TRUE)
  # }
  ### 'LC1980_bbt' can be retrieved quickly with: 
  data(LC1980_bbt)

  summary(LC1980_bbt)
  plot(LC1980_bbt)

Run the code above in your browser using DataLab