Learn R Programming

basicspace (version 0.25)

plot.boot_blackbt: Bootstrapped Blackbox Transpose Stimulus Plots

Description

plot.boot_blackbt reads an boot_blackbt object and plots a dotchart of the stimuli with estimated confidence intervals.

Usage

# S3 method for boot_blackbt
plot(x, ...)

Value

A dotchart of estimated stimulus locations, with 95 percent confidence intervals. Point estimates are estimates from the original data set.

Arguments

x

an boot_blackbt output object.

...

other arguments to plot.

Author

Keith Poole [email protected]

Howard Rosenthal [email protected]

Jeffrey Lewis [email protected]

James Lo [email protected]

Royce Carroll [email protected]

Christopher Hare [email protected]

References

David A. Armstrong II, Ryan Bakker, Royce Carroll, Christopher Hare, Keith T. Poole, and Howard Rosenthal. 2021. Analyzing Spatial Models of Choice and Judgment. 2nd ed. Statistics in the Social and Behavioral Sciences Series. Boca Raton, FL: Chapman & Hall/CRC. doi: 10.1201/9781315197609

Keith T. Poole, Jeffrey B. Lewis, Howard Rosenthal, James Lo, and Royce Carroll. 2016. ``Recovering a Basic Space from Issue Scales in R.'' Journal of Statistical Software 69(7): 1-21. doi:10.18637/jss.v069.i07

Keith T. Poole. 1998. ``Recovering a Basic Space From a Set of Issue Scales.'' American Journal of Political Science 42(3): 954-993. doi: 10.2307/2991737

See Also

'blackbox_transpose', 'boot_blackbt'.

Examples

Run this code
  ### Loads the Liberal-Conservative scales from the 1980 ANES.
  data(LC1980)
  data <- LC1980[,-1]	#Dump the column of self-placements

  # \donttest{ 
  bootbbt <- boot_blackbt(data, missing=c(0,8,9), dims=1, 
    minscale=8, iter=10)
  # }
  ### 'bootbbt' can be retrieved quickly with: 
  data(bootbbt)

  plot.boot_blackbt(bootbbt)

Run the code above in your browser using DataLab